emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] /srv/bzr/emacs/trunk r106678: Spelling fixes.


From: Paul Eggert
Subject: [Emacs-diffs] /srv/bzr/emacs/trunk r106678: Spelling fixes.
Date: Wed, 14 Dec 2011 23:24:10 -0800
User-agent: Bazaar (2.3.1)

------------------------------------------------------------
revno: 106678
committer: Paul Eggert <address@hidden>
branch nick: trunk
timestamp: Wed 2011-12-14 23:24:10 -0800
message:
  Spelling fixes.
modified:
  configure.in
  doc/misc/ede.texi
  doc/misc/semantic.texi
  etc/NEWS.22
  lisp/arc-mode.el
  lisp/cedet/semantic/scope.el
  lisp/dframe.el
  lisp/emacs-lisp/pcase.el
  lisp/filesets.el
  lisp/international/ccl.el
  lisp/international/quail.el
  lisp/international/titdic-cnv.el
  lisp/org/org-protocol.el
  lisp/printing.el
  lisp/progmodes/cperl-mode.el
  lisp/progmodes/gdb-mi.el
  lisp/progmodes/idlwave.el
  src/ChangeLog.11
  src/ChangeLog.8
  src/charset.c
  src/charset.h
  src/font.h
  src/w16select.c
  src/w32font.c
=== modified file 'configure.in'
--- a/configure.in      2011-12-10 12:33:07 +0000
+++ b/configure.in      2011-12-15 07:24:10 +0000
@@ -1683,7 +1683,7 @@
   ## Use mmap directly for allocating larger buffers.
   ## FIXME this comes from src/s/{gnu,gnu-linux}.h:
   ## #ifdef DOUG_LEA_MALLOC; #undef REL_ALLOC; #endif
-  ## Does the AC_FUNC_MMAP test below make this check unecessary?
+  ## Does the AC_FUNC_MMAP test below make this check unnecessary?
   case "$opsys" in
     gnu*) REL_ALLOC=no ;;
   esac

=== modified file 'doc/misc/ede.texi'
--- a/doc/misc/ede.texi 2011-11-23 07:03:56 +0000
+++ b/doc/misc/ede.texi 2011-12-15 07:24:10 +0000
@@ -705,11 +705,11 @@
 by the @samp{ede-speedbar} interface.
 @item ede-want-file-p
 Return non-nil if a target will accept a given file.
-It is generally unecessary to override this.  See the section on source
+It is generally unnecessary to override this.  See the section on source
 code.
 @item ede-buffer-mine
 Return non-nil if a buffer belongs to this target.  Used during
-association when a file is loaded.  It is generally unecessary to
+association when a file is loaded.  It is generally unnecessary to
 override this unless you keep auxiliary files.
 @end table
 

=== modified file 'doc/misc/semantic.texi'
--- a/doc/misc/semantic.texi    2011-11-25 07:14:48 +0000
+++ b/doc/misc/semantic.texi    2011-12-15 07:24:10 +0000
@@ -380,7 +380,7 @@
 
 @item semanticdb-ref.el
 Tracks crossreferences.   Cross references are needed when buffer is
-reparsed, and must alert other tables that any dependant caches may
+reparsed, and must alert other tables that any dependent caches may
 need to be flushed.  References are in the form of include files.
 
 @end table

=== modified file 'etc/NEWS.22'
--- a/etc/NEWS.22       2011-11-27 04:43:11 +0000
+++ b/etc/NEWS.22       2011-12-15 07:24:10 +0000
@@ -4273,7 +4273,7 @@
 further filter candidate files.
 
 One advantage of using this function is that the list of suffixes in
-`exec-suffixes' is OS-dependant, so this function will find
+`exec-suffixes' is OS-dependent, so this function will find
 executables without polluting Lisp code with OS dependencies.
 
 *** The new function `file-remote-p' tests a file name and returns

=== modified file 'lisp/arc-mode.el'
--- a/lisp/arc-mode.el  2011-11-17 17:40:48 +0000
+++ b/lisp/arc-mode.el  2011-12-15 07:24:10 +0000
@@ -860,13 +860,13 @@
          dir)))
     (if (or alien (file-exists-p fullname))
        (progn
-         ;; Maked sure all the leading directories in
+         ;; Make sure all the leading directories in
          ;; archive-local-name exist under archive-tmpdir, so that
          ;; the directory structure recorded in the archive is
          ;; reconstructed in the temporary directory.
          (make-directory (file-name-directory tmpfile) t)
          (make-temp-file tmpfile))
-      ;; Maked sure all the leading directories in `fullname' exist
+      ;; Make sure all the leading directories in `fullname' exist
       ;; under archive-tmpdir.  This is necessary for nested archives
       ;; (`archive-extract' sets `archive-remote' to t in case
       ;; an archive occurs inside another archive).

=== modified file 'lisp/cedet/semantic/scope.el'
--- a/lisp/cedet/semantic/scope.el      2011-11-20 07:30:16 +0000
+++ b/lisp/cedet/semantic/scope.el      2011-12-15 07:24:10 +0000
@@ -725,7 +725,7 @@
              (oset scopecache localargs localargs)
              (oset scopecache localvar localvar)
              )))
-       ;; Make sure we become dependant on the typecache.
+       ;; Make sure we become dependent on the typecache.
        (semanticdb-typecache-add-dependant scopecache)
        ;; Handy debug output.
        (when (called-interactively-p 'any)

=== modified file 'lisp/dframe.el'
--- a/lisp/dframe.el    2011-11-27 04:43:11 +0000
+++ b/lisp/dframe.el    2011-12-15 07:24:10 +0000
@@ -221,7 +221,7 @@
     (define-key map [mouse-2] 'dframe-click)
     ;; This is the power click for new frames, or refreshing a cache
     (define-key map [S-mouse-2] 'dframe-power-click)
-    ;; This adds a small unecessary visual effect
+    ;; This adds a small unnecessary visual effect
     ;;(define-key map [down-mouse-2] 'dframe-quick-mouse)
 
     (define-key map [down-mouse-3] 'dframe-popup-kludge)

=== modified file 'lisp/emacs-lisp/pcase.el'
--- a/lisp/emacs-lisp/pcase.el  2011-03-16 20:08:39 +0000
+++ b/lisp/emacs-lisp/pcase.el  2011-12-15 07:24:10 +0000
@@ -363,12 +363,12 @@
     (dolist (branch rest)
       (let* ((match (car branch))
              (code&vars (cdr branch))
-             (splitted
+             (split
               (pcase--split-match sym splitter match)))
-        (unless (eq (car splitted) :pcase--fail)
-          (push (cons (car splitted) code&vars) then-rest))
-        (unless (eq (cdr splitted) :pcase--fail)
-          (push (cons (cdr splitted) code&vars) else-rest))))
+        (unless (eq (car split) :pcase--fail)
+          (push (cons (car split) code&vars) then-rest))
+        (unless (eq (cdr split) :pcase--fail)
+          (push (cons (cdr split) code&vars) else-rest))))
     (cons (nreverse then-rest) (nreverse else-rest))))
 
 (defun pcase--split-consp (syma symd pat)

=== modified file 'lisp/filesets.el'
--- a/lisp/filesets.el  2011-11-27 04:43:11 +0000
+++ b/lisp/filesets.el  2011-12-15 07:24:10 +0000
@@ -453,7 +453,7 @@
   :group 'filesets)
 
 (defcustom filesets-max-entry-length 50
-  "Truncate names of splitted submenus to this length."
+  "Truncate names of split submenus to this length."
   :set (function filesets-set-default)
   :type 'integer
   :group 'filesets)

=== modified file 'lisp/international/ccl.el'
--- a/lisp/international/ccl.el 2011-12-05 08:55:25 +0000
+++ b/lisp/international/ccl.el 2011-12-15 07:24:10 +0000
@@ -1469,7 +1469,7 @@
        | de-sjis
 
        ;; If ARG_0 and ARG_1 are the first and second code point of
-       ;; JISX0208 character CHAR, and SJIS is the correponding
+       ;; JISX0208 character CHAR, and SJIS is the corresponding
        ;; Shift-JIS code,
        ;; (REG = ARG_0 en-sjis ARG_1) means:
        ;;      ((REG = HIGH)

=== modified file 'lisp/international/quail.el'
--- a/lisp/international/titdic-cnv.el  2011-12-04 08:02:42 +0000
+++ b/lisp/international/titdic-cnv.el  2011-12-15 07:24:10 +0000
@@ -103,7 +103,7 @@
 
 \\<quail-translation-docstring>
 
-For double-width GB2312 characters correponding to ASCII, use the
+For double-width GB2312 characters corresponding to ASCII, use the
 input method `chinese-qj'.")
 
     ("chinese-ecdict" "$(05CKH(B"
@@ -191,7 +191,7 @@
 a Pinyin, the next \"3\" specifies tone, and the last \"3\" selects
 the third character from the candidate list.
 
-For double-width GB2312 characters correponding to ASCII, use the
+For double-width GB2312 characters corresponding to ASCII, use the
 input method `chinese-qj'.")
 
     ("chinese-zozy" "$(0I\0D(B"

=== modified file 'lisp/org/org-protocol.el'
--- a/lisp/org/org-protocol.el  2011-12-04 08:02:42 +0000
+++ b/lisp/org/org-protocol.el  2011-12-15 07:24:10 +0000
@@ -546,8 +546,8 @@
               (when (string-match proto fname)
                 (let* ((func (plist-get (cdr prolist) :function))
                        (greedy (plist-get (cdr prolist) :greedy))
-                       (splitted (split-string fname proto))
-                       (result (if greedy restoffiles (cadr splitted))))
+                       (split (split-string fname proto))
+                       (result (if greedy restoffiles (cadr split))))
                   (when (plist-get (cdr prolist) :kill-client)
                    (message "Greedy org-protocol handler. Killing client.")
                    (server-edit))

=== modified file 'lisp/printing.el'
--- a/lisp/printing.el  2011-12-09 03:12:38 +0000
+++ b/lisp/printing.el  2011-12-15 07:24:10 +0000
@@ -4710,12 +4710,12 @@
 
    M-x pr-ps-fast-fire RET
       The command prompts the user for a N-UP value and printing will
-      immediatelly be done using the current active printer.
+      immediately be done using the current active printer.
 
    C-u   M-x pr-ps-fast-fire RET
    C-u 0 M-x pr-ps-fast-fire RET
       The command prompts the user for a N-UP value and also for a current
-      PostScript printer, then printing will immediatelly be done using the new
+      PostScript printer, then printing will immediately be done using the new
       current active printer.
 
    C-u 1 M-x pr-ps-fast-fire RET
@@ -4736,7 +4736,7 @@
    If it's nil, send the image to the printer.
 
    If it's a list or an integer lesser or equal to zero, the command prompts
-   the user for a current PostScript printer, then printing will immediatelly
+   the user for a current PostScript printer, then printing will immediately
    be done using the new current active printer.
 
    If it's an integer equal to 1, the command prompts the user for a file name
@@ -4749,7 +4749,7 @@
    instead of sending it to the printer.
 
    If it's a symbol which it's defined in `pr-ps-printer-alist', it's the new
-   active printer and printing will immediatelly be done using the new active
+   active printer and printing will immediately be done using the new active
    printer.
 
    Otherwise, send the image to the printer.
@@ -4800,7 +4800,7 @@
    If it's nil, the printing is sent to the current active text printer.
 
    If it's a symbol which it's defined in `pr-txt-printer-alist', it's the new
-   active printer and printing will immediatelly be done using the new active
+   active printer and printing will immediately be done using the new active
    printer.
 
    If it's non-nil, the command prompts the user for a new active text printer.

=== modified file 'lisp/progmodes/cperl-mode.el'
--- a/lisp/progmodes/gdb-mi.el  2011-12-11 13:17:07 +0000
+++ b/lisp/progmodes/gdb-mi.el  2011-12-15 07:24:10 +0000
@@ -3865,7 +3865,7 @@
 If BUF is already displayed in some window, show it, deiconifying
 the frame if necessary. Otherwise, find least recently used
 window and show BUF there, if the window is not used for GDB
-already, in which case that window is splitted first."
+already, in which case that window is split first."
   (let ((answer (get-buffer-window buf (or frame 0))))
     (if answer
        (display-buffer buf nil (or frame 0)) ;Deiconify frame if necessary.

=== modified file 'lisp/progmodes/idlwave.el'
--- a/lisp/progmodes/idlwave.el 2011-12-04 08:02:42 +0000
+++ b/lisp/progmodes/idlwave.el 2011-12-15 07:24:10 +0000
@@ -2464,7 +2464,7 @@
 (defun idlwave-down-block (&optional arg)
   "Go down a block.
 With ARG: ARG >= 0 go forwards, ARG < 0 go backwards.
-Returns non-nil if successfull."
+Returns non-nil if successful."
   (interactive "p")
   (let (status)
     (if (< arg 0)

=== modified file 'src/ChangeLog.11'
--- a/src/ChangeLog.11  2011-12-04 08:02:42 +0000
+++ b/src/ChangeLog.11  2011-12-15 07:24:10 +0000
@@ -30657,7 +30657,7 @@
        (display_buffer): Do not set split_height_threshold to twice the
        value of window_min_height to avoid changing the value of a
        customizable variable.  Rather explicitly check whether the
-       height of the window that shall be splitted is at least as large
+       height of the window that shall be split is at least as large
        as split_height_threshold.
        (Fwindow_full_width_p): New defun.
        (syms_of_window): Defsubr it.

=== modified file 'src/ChangeLog.8'
--- a/src/ChangeLog.8   2011-12-14 21:05:20 +0000
+++ b/src/ChangeLog.8   2011-12-15 07:24:10 +0000
@@ -11485,7 +11485,7 @@
        Substitute homedir by `~' also in default_filename.
 
        * xdisp.c (try_window_id): Fix computation of tab_offset when
-       backing up over a character that is splitted across lines.
+       backing up over a character that is split across lines.
 
 1999-05-08  Kenichi HANDA  <address@hidden>
 

=== modified file 'src/charset.c'
--- a/src/charset.c     2011-11-27 04:43:11 +0000
+++ b/src/charset.c     2011-12-15 07:24:10 +0000
@@ -1660,7 +1660,7 @@
 }
 
 
-/* Return a character correponding to the code-point CODE of
+/* Return a character corresponding to the code-point CODE of
    CHARSET.  */
 
 int

=== modified file 'src/charset.h'
--- a/src/charset.h     2011-11-14 21:00:24 +0000
+++ b/src/charset.h     2011-12-15 07:24:10 +0000
@@ -238,7 +238,7 @@
   int unified_p;
 };
 
-/* Hash table of charset symbols vs. the correponding attribute
+/* Hash table of charset symbols vs. the corresponding attribute
    vectors.  */
 extern Lisp_Object Vcharset_hash_table;
 
@@ -389,7 +389,7 @@
 #endif
 
 
-/* Return a character correponding to the code-point CODE of CHARSET.
+/* Return a character corresponding to the code-point CODE of CHARSET.
    Try some optimization before calling decode_char.  */
 
 #define DECODE_CHAR(charset, code)                                     \

=== modified file 'src/font.h'
--- a/src/font.h        2011-12-06 01:30:54 +0000
+++ b/src/font.h        2011-12-15 07:24:10 +0000
@@ -621,7 +621,7 @@
   /* Optional.
      Get coordinates of the INDEXth anchor point of the glyph whose
      code is CODE.  Store the coordinates in *X and *Y.  Return 0 if
-     the operations was successfull.  Otherwise return -1.  */
+     the operations was successful.  Otherwise return -1.  */
   int (*anchor_point) (struct font *font, unsigned code, int index,
                        int *x, int *y);
 

=== modified file 'src/w16select.c'
--- a/src/w16select.c   2011-09-09 01:06:52 +0000
+++ b/src/w16select.c   2011-12-15 07:24:10 +0000
@@ -114,7 +114,7 @@
   return regs.x.ax;
 }
 
-/* Open the clipboard, return non-zero if successfull.  */
+/* Open the clipboard, return non-zero if successful.  */
 unsigned
 open_clipboard (void)
 {
@@ -137,7 +137,7 @@
   return regs.x.ax;
 }
 
-/* Empty clipboard, return non-zero if successfull.  */
+/* Empty clipboard, return non-zero if successful.  */
 unsigned
 empty_clipboard (void)
 {
@@ -207,7 +207,7 @@
     }
 }
 
-/* Copy data into the clipboard, return zero if successfull.  */
+/* Copy data into the clipboard, return zero if successful.  */
 unsigned
 set_clipboard_data (unsigned Format, void *Data, unsigned Size, int Raw)
 {
@@ -405,7 +405,7 @@
   return (unsigned) (dp - (unsigned char *)Data - 1);
 }
 
-/* Close clipboard, return non-zero if successfull.  */
+/* Close clipboard, return non-zero if successful.  */
 unsigned
 close_clipboard (void)
 {
@@ -730,4 +730,3 @@
 }
 
 #endif /* MSDOS */
-

=== modified file 'src/w32font.c'
--- a/src/w32font.c     2011-11-20 19:35:27 +0000
+++ b/src/w32font.c     2011-12-15 07:24:10 +0000
@@ -786,7 +786,7 @@
    Optional.
    Get coordinates of the INDEXth anchor point of the glyph whose
    code is CODE.  Store the coordinates in *X and *Y.  Return 0 if
-   the operations was successfull.  Otherwise return -1.
+   the operations was successful.  Otherwise return -1.
 static int
 w32font_anchor_point (struct font *font, unsigned code,
                                  int index, int *x, int *y);


reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- a/lisp/international/quail.el       2011-12-04 08:02:42 +0000
+++ b/lisp/international/quail.el       2011-12-15 07:24:10 +0000
@@ -2832,7 +2832,7 @@
 TRANSITION-n-m are transition rules from STATE-n, and have the form
 \(RULES . STATE-x) or RULES, where STATE-x is one of STATE-n above,
 RULES is a symbol whose value is an alist of keys \(string) vs the
-correponding characters or strings.  The format of the symbol value of
+corresponding characters or strings.  The format of the symbol value of
 RULES is the same as arguments to `quail-define-rules'.
 
 If TRANSITION-n-m has the form (RULES . STATE-x), it means that
@@ -2846,7 +2846,7 @@
 function `quail-install-map' (which see)."
   (let ((state-alist (mapcar (lambda (x) (list (car x))) table))
        tail elt)
     ;; STATE-ALIST is an alist of states vs the correponding sub Quail
     ;; map.  It is now initialized to ((STATE-0) (STATE-1) ...).
     ;; Set key sequence mapping rules in cdr part of each element.
     (while table
@@ -2846,7 +2846,7 @@
   (let ((state-alist (mapcar (lambda (x) (list (car x))) table))
        tail elt)
-    ;; STATE-ALIST is an alist of states vs the correponding sub Quail
+    ;; STATE-ALIST is an alist of states vs the corresponding sub Quail
     ;; map.  It is now initialized to ((STATE-0) (STATE-1) ...).
     ;; Set key sequence mapping rules in cdr part of each element.

=== modified file 'lisp/international/titdic-cnv.el'
--- a/lisp/progmodes/cperl-mode.el      2011-11-27 04:43:11 +0000
+++ b/lisp/progmodes/cperl-mode.el      2011-12-15 07:24:10 +0000
@@ -958,7 +958,7 @@
   `cperl-array-face'                   Array names
   `cperl-hash-face'                    Hash names
   `font-lock-comment-face'     Comments, PODs and whatever is considered
-                               syntaxically to be not code
+                               syntactically to be not code
   `font-lock-constant-face'    HERE-doc delimiters, labels, delimiters of
                                2-arg operators s/y/tr/ or of RExen,
   `font-lock-warning-face'     Special-cased m// and s//foo/,
@@ -970,7 +970,7 @@
   `cperl-nonoverridable-face'  Non-overridable keywords, modifiers of RExen
   `font-lock-string-face'      Strings, qw() constructs, RExen, POD sections,
                                literal parts and the terminator of formats
-                               and whatever is syntaxically considered
+                               and whatever is syntactically considered
                                as string literals
   `font-lock-type-face'                Overridable keywords
   `font-lock-variable-name-face' Variable declarations, indirect array and
@@ -1537,8 +1537,8 @@
 since most the time you mean \"less\".  CPerl mode tries to guess
 whether you want to type pair <>, and inserts is if it
 appropriate.  You can set `cperl-electric-parens-string' to the string that
-contains the parenths from the above list you want to be electrical.
-Electricity of parenths is controlled by `cperl-electric-parens'.
+contains the parens from the above list you want to be electrical.
+Electricity of parens is controlled by `cperl-electric-parens'.
 You may also set `cperl-electric-parens-mark' to have electric parens
 look for active mark and \"embrace\" a region if possible.'
 
@@ -3517,7 +3517,7 @@
 (defvar font-lock-warning-face)
 
 (defun cperl-find-sub-attrs (&optional st-l b-fname e-fname pos)
-  "Syntaxically mark (and fontify) attributes of a subroutine.
+  "Syntactically mark (and fontify) attributes of a subroutine.
 Should be called with the point before leading colon of an attribute."
   ;; Works *before* syntax recognition is done
   (or st-l (setq st-l (list nil)))     ; Avoid overwriting '()
@@ -4994,7 +4994,7 @@
          (setq top (point))
          ;; Plan A: if line has an unfinished paren-group, go to end-of-group
          (while (= -1 (nth 0 (parse-partial-sexp (point) tmp-end -1)))
-           (setq top (point)))         ; Get the outermost parenths in line
+           (setq top (point)))         ; Get the outermost parens in line
          (goto-char top)
          (while (< (point) tmp-end)
            (parse-partial-sexp (point) tmp-end nil t) ; To start-sexp or eol
@@ -5906,7 +5906,7 @@
                       3 font-lock-variable-name-face)))
            '("\\<for\\(each\\)?\\([ \t]+\\(my\\|local\\|our\\)\\)?[ 
\t]*\\(\\$[a-zA-Z_][a-zA-Z_0-9]*\\)[ \t]*("
              4 font-lock-variable-name-face)
            ;; Avoid $!, and s!!, qq!! etc. when not fontifying syntaxically
            '("\\(?:^\\|[^smywqrx$]\\)\\(!\\)" 1 font-lock-negation-char-face)
            '("\\[\\(\\^\\)" 1 font-lock-negation-char-face prepend)))
          (setq
@@ -5906,7 +5906,7 @@
\t]*\\(\\$[a-zA-Z_][a-zA-Z_0-9]*\\)[ \t]*("
              4 font-lock-variable-name-face)
-           ;; Avoid $!, and s!!, qq!! etc. when not fontifying syntaxically
+           ;; Avoid $!, and s!!, qq!! etc. when not fontifying syntactically
            '("\\(?:^\\|[^smywqrx$]\\)\\(!\\)" 1 font-lock-negation-char-face)
            '("\\[\\(\\^\\)" 1 font-lock-negation-char-face prepend)))

=== modified file 'lisp/progmodes/gdb-mi.el'